/* $Id: main.c 9812 2007-08-17 16:17:42Z toady $
 * Written by Sebastien Tricaud <toady@gscore.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
;5B * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
*/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <glib.h>
#include <glib/gthread.h>

#include "prelude-init.h"
#include "brouette-gtk-status.h"
#include "config.h"

int main(int argc, char **argv)
{
        GError *error;
	char *manager_addr;

	gboolean conf_loaded = FALSE;
        int opt, ret = 0;


        g_thread_init(NULL);

	while ((opt = getopt(argc, argv, "c:h")) != -1) {
		switch (opt) {
		case 'c':
			ret = config_init(optarg);
			if ( ! ret ) {
				g_critical("[%s:%s:%d] Cannot load configuration file\n", __FILE__, __FUNCTION__, __LINE__);
				exit(-1);
			}
			
			conf_loaded = TRUE;
			break;
		case 'h':
		default: 
			fprintf(stderr, "Usage: %s [-c config_file]\n\t%s [-h]\n",
				argv[0], argv[0]);
			exit(-1);
		}
	}

        brouette_gtk_status_init(argc, argv);

	if ( ! conf_loaded ) {
		ret = config_init(NULL);
		if ( ! ret ) {
			g_critical("[%s:%s:%d] Cannot load configuration file\n", __FILE__, __FUNCTION__, __LINE__);
			exit(-1);
		}
	}

	manager_addr = config_get_val("manager", "address");
	if ( ! manager_addr ) {
		g_critical("No manager address found in config");
		exit(-1);
	}

        ret = initialize_prelude();
        if ( ret < 0 ) {
                printf("Cannot initialize prelude\n");
        }

        if ( ! g_thread_create((GThreadFunc)connect_prelude, manager_addr, TRUE, &error) )
		g_critical("Cannot create the prelude connection thread!");

	brouette_gtk_status_run();
        
	gdk_threads_enter();
        brouette_gtk_status_main();
	gdk_threads_leave();

	config_destroy();

        return 0;

}
