/* $Id: prelude-init.c 9840 2007-08-23 09:13:56Z toady $
 * Written by Sebastien Tricaud <toady@gscore.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
*/

#include <glib.h>

#include <stdio.h>

#include <libprelude/prelude.h>
#include <libprelude/prelude-message-id.h>
#include <libprelude/idmef-message-print.h>

#include "prelude-init.h"

#include "alert-callback.h"
#include "config.h"

static prelude_client_t *client;
static unsigned int refresh_timeout = 0;

extern int 
initialize_prelude(void)
{
        int ret;
	char *buffer;

        ret = prelude_init(NULL, NULL);
        if ( ret < 0 ) {
                prelude_perror(ret, "error initializing the prelude library");
                return ret;
        }

        ret = prelude_client_new(&client, "brouette");
        if ( ret < 0 ) {
                prelude_perror(ret, "error initializing prelude client");
                return ret;
        }

        prelude_client_set_required_permission(client, PRELUDE_CONNECTION_PERMISSION_IDMEF_READ);

	buffer = config_get_val("general", "timeout");
	if ( ! buffer )
		buffer = "2";	/* Default value */

	refresh_timeout = atoi(buffer);

        return 0;
}

extern int 
check_for_event(void* data)
{
        prelude_connection_pool_t *pool = data;
        int ret;

	if ( ! data ) {
		printf("Cannot get data from the pool");
		return -1;
	}

        ret = prelude_connection_pool_check_event(pool, 0, event_cb, NULL);
        if ( ret < 0 ) {
                prelude_perror(ret, "error setting callback");
                return -1;
        }

}

extern int
connect_prelude(gpointer *data)
{
        int ret;
        prelude_connection_pool_t *pool = NULL;
        const char *manager_addr = (const char *)data;
        
        prelude_connection_pool_new(&pool, 
                                    prelude_client_get_profile(client), 
                                    prelude_client_get_required_permission(client));

       ret = prelude_connection_pool_set_connection_string(pool, manager_addr);
       if ( ret < 0 ) {
                prelude_perror(ret, "error setting new prelude connection string");
                return -1;
        }

       prelude_client_set_connection_pool(client, pool);

        ret = prelude_connection_pool_init(pool);
        if ( ret < 0 ) {
                prelude_perror(ret, "error initializing connection pool");
                return -1;
        }


        while (1) {
	        sleep(refresh_timeout);
                check_for_event(pool);
        }


	prelude_client_destroy(client, PRELUDE_CLIENT_EXIT_STATUS_SUCCESS);

        return 0;
}
